@@ -33,6 +33,8 @@ class People:
             A MemberDetails object containing all data.
 
         Raises:
+            requests.exceptions.RequestException:
+                For errors while executing the HTTP call
             PermissionError:
                 If the current user does not have permission to view personal
                 data for the requested member.
@@ -62,6 +64,8 @@ class People:
             A MemberRolesDict object containing all data.
 
         Raises:
+            requests.exceptions.RequestException:
+                For errors while executing the HTTP call
             PermissionError:
                 If the current user does not have permission to view roles
                 data for the requested member.
@@ -85,24 +89,14 @@ class People:
             MemberRolePopup object with detail on the role
 
         Raises:
+            requests.exceptions.RequestException:
+                For errors while executing the HTTP call
             PermissionError:
                 If the current user does not have permission to view role data
 
         """
         return self._scraper.get_roles_detail(role_number)
 
-    def training(self, membership_num: int) -> schema.MemberTrainingTab:
-        """Gets training tab data for a given member.
-
-        Args:
-            membership_num: Membership Number to use
-
-        Returns:
-            A MemberTrainingTab object containing all data.
-
-        """
-        return self._scraper.get_training_tab(membership_num, ongoing_only=False)
-
     def permits(self, membership_num: int) -> schema.MemberPermitsList:
         """Gets permits tab data for a given member.
 
@@ -110,12 +104,39 @@ class People:
             membership_num: Membership Number to use
 
         Returns:
+            requests.exceptions.RequestException:
+                For errors while executing the HTTP call
             A MemberPermitsList object containing all data.
 
         """
         return self._scraper.get_permits_tab(membership_num)
 
+    def training(self, membership_num: int) -> schema.MemberTrainingTab:
+        """Gets training tab data for a given member.
+
+        Args:
+            membership_num: Membership Number to use
+
+        Returns:
+            requests.exceptions.RequestException:
+                For errors while executing the HTTP call
+            A MemberTrainingTab object containing all data.
+
+        """
+        return self._scraper.get_training_tab(membership_num, ongoing_only=False)
+
     def ongoing_learning(self, membership_num: int) -> schema.MemberMOGLList:
+        """Gets ongoing learning data for a given member.
+
+        Args:
+            membership_num: Membership Number to use
+
+        Returns:
+            requests.exceptions.RequestException:
+                For errors while executing the HTTP call
+            A MemberMOGLList object containing all data.
+
+        """
         return self._scraper.get_training_tab(membership_num, ongoing_only=True)
 
     def awards(self, membership_num: int) -> list[schema.MemberAward]:
@@ -128,6 +149,8 @@ class People:
             A MemberAward object containing all data.
 
         Raises:
+            requests.exceptions.RequestException:
+                For errors while executing the HTTP call
             PermissionError:
                 If the current user does not have permission to view awards
                 data for the requested member.
@@ -145,6 +168,8 @@ class People:
             A list of MemberDisclosure objects containing all data.
 
         Raises:
+            requests.exceptions.RequestException:
+                For errors while executing the HTTP call
             PermissionError:
                 If the current user does not have permission to view
                 disclosure data for the requested member.
@@ -164,6 +189,8 @@ class People:
             A MemberDisclosure objects containing disclosure data.
 
         Raises:
+            requests.exceptions.RequestException:
+                For errors while executing the HTTP call
             PermissionError:
                 If the current user does not have permission to view
                 disclosure data for the requested member.
